@@ -11,8 +11,7 @@ package Net::BitTorrent::DHT;
     use Net::BitTorrent::Util qw[:bencode :compact];
     use Net::BitTorrent::Protocol qw[:dht];
     use Net::BitTorrent::Version;
-    use version qw[qv];
-    our $VERSION_BASE = 49; our $UNSTABLE_RELEASE = 99; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
     my @CONTENTS
         = \my (%_client, %tid, %node_id, %outstanding_p, %nodes, %tracking);
     my %REGISTRY;
@@ -107,8 +106,8 @@ package Net::BitTorrent::DHT;
         my $ok = $_client{refaddr $self}->_event(q[ip_filter],
              {Address => sprintf q[%s:%d], $args->{q[ip]}, $args->{q[port]}});
         if (defined $ok and $ok == 0) { return; }
-        my $_resolved = inet_aton($args->{q[ip]});
-        return if !$_resolved;
+        my $_resolved = inet_aton($args->{q[ip]});    # XXX - delay resolving
+        return if !$_resolved;    # because it's often slow
         my $paddr = pack_sockaddr_in($args->{q[port]}, $_resolved);
         $nodes{refaddr $self}{$paddr} = {
                                        birth     => time,
@@ -790,6 +789,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: DHT.pm 3f42870 2009-02-12 05:01:56Z sanko@cpan.org $
+=for svn $Id: DHT.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
 
 =cut
