@@ -10,8 +10,7 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
     use Fcntl qw[F_SETFL O_NONBLOCK];
     use lib q[../../../../../lib];
     use Net::BitTorrent::Util qw[:bencode :compact];
-    use version qw[qv];
-    our $VERSION_BASE = 49; our $UNSTABLE_RELEASE = 99; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 1; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
     my (@CONTENTS)
         = \my (%_url,   %_tier,     %resolve,
                %_event, %_socket,   %_data_out,
@@ -136,8 +135,8 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
             q[uploaded] => $_tier{refaddr $self}->_torrent->uploaded(),
             q[downloaded] => $_tier{refaddr $self}->_torrent->downloaded(),
             q[left]       => (
-                $_tier{refaddr $self}->_torrent->raw_data(1)
-                    ->{q[info]}{q[piece length]} * sum(
+                $_tier{refaddr $self}->_torrent->metadata(1)
+                    ->{q[piece length]} * sum(
                     split(
                         q[],
                         unpack(
@@ -157,8 +156,8 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
              : ()
             )
         );
-        my $url 
-            = $path 
+        my $url
+            = $path
             . ($path =~ m[\?] ? q[&] : q[?])
             . (join q[&],
                map { sprintf q[%s=%s], $_, $query_hash{$_} }
@@ -421,6 +420,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: HTTP.pm 3f42870 2009-02-12 05:01:56Z sanko@cpan.org $
+=for svn $Id: HTTP.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
 
 =cut
