@@ -3,10 +3,10 @@ use strict;
 use warnings;
 use Data::Dump;
 use Net::BitTorrent::Torrent;
-my $torrent = Net::BitTorrent::Torrent->new({Path => 'a.legal.torrent'})
+my $torrent = Net::BitTorrent::Torrent->new({Path => '956_dht.torrent'})
     or exit;
 $torrent->as_string(1);
-dd $torrent->raw_data(1);
+dd $torrent->metadata(1);
 print map { qq[\n] . $_->path } @{$torrent->files};
 
 =pod
@@ -51,7 +51,7 @@ to give you a rundown of what can be parsed from the file.
 =item Line 9
 
 Prints a dump of the .torrent file's
-L<metadata|Net::BitTorrent::Torrent/"raw_data ( [ RAW ] )">.
+L<metadata|Net::BitTorrent::Torrent/"metadata ( [ RAW ] )">.
 
 =item Line 10
 
@@ -75,7 +75,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -91,6 +91,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 001-torrent-info.pl a7a7e9d 2009-02-09 04:49:58Z sanko@cpan.org $
+=for svn $Id: 001-torrent-info.pl c260f8c 2009-09-07 02:35:29Z sanko@cpan.org $
 
 =cut
